summaryrefslogtreecommitdiffstats
path: root/lib/antlr
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 06:08:18 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 06:08:18 +0000
commit330c33ab6f97b279737bf9527c9add7bb1475450 (patch)
tree85cb998d3077ae295d65944ebb4d0189fc660ead /lib/antlr
parent093de0db4fea89b3f94a2359c6981f353d035eb7 (diff)
downloadtdevelop-330c33ab6f97b279737bf9527c9add7bb1475450.tar.gz
tdevelop-330c33ab6f97b279737bf9527c9add7bb1475450.zip
rename the following methods:
tqfind find tqreplace replace tqcontains contains git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdevelop@1246075 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'lib/antlr')
-rw-r--r--lib/antlr/antlr/TokenStreamRewriteEngine.hpp28
1 files changed, 14 insertions, 14 deletions
diff --git a/lib/antlr/antlr/TokenStreamRewriteEngine.hpp b/lib/antlr/antlr/TokenStreamRewriteEngine.hpp
index 6aa948fe..9fab08c2 100644
--- a/lib/antlr/antlr/TokenStreamRewriteEngine.hpp
+++ b/lib/antlr/antlr/TokenStreamRewriteEngine.hpp
@@ -34,7 +34,7 @@ namespace antlr {
* Useful for dumping out the input stream exactly after doing some
* augmentation or other manipulations. Tokens are index from 0..n-1
*
* You can insert stuff, tqreplace, and delete chunks. Note that the
* operations are done lazily--only if you convert the buffer to a
* String. This is very efficient because you are not moving data around
* all the time. As the buffer of tokens is converted to strings, the
@@ -262,43 +262,43 @@ public:
addToSortedRewriteList(programName, new InsertBeforeOp(index,text));
}
- void tqreplace(size_t index, const ANTLR_USE_NAMESPACE(std)string& text)
+ void replace(size_t index, const ANTLR_USE_NAMESPACE(std)string& text)
{
- tqreplace(DEFAULT_PROGRAM_NAME, index, index, text);
+ replace(DEFAULT_PROGRAM_NAME, index, index, text);
}
- void tqreplace( size_t from, size_t to,
+ void replace( size_t from, size_t to,
const ANTLR_USE_NAMESPACE(std)string& text)
{
- tqreplace(DEFAULT_PROGRAM_NAME, from, to, text);
+ replace(DEFAULT_PROGRAM_NAME, from, to, text);
}
- void tqreplace( RefTokenWithIndex indexT,
+ void replace( RefTokenWithIndex indexT,
const ANTLR_USE_NAMESPACE(std)string& text )
{
- tqreplace(DEFAULT_PROGRAM_NAME, indexT->getIndex(), indexT->getIndex(), text);
+ replace(DEFAULT_PROGRAM_NAME, indexT->getIndex(), indexT->getIndex(), text);
}
- void tqreplace( RefTokenWithIndex from,
+ void replace( RefTokenWithIndex from,
RefTokenWithIndex to,
const ANTLR_USE_NAMESPACE(std)string& text )
{
- tqreplace(DEFAULT_PROGRAM_NAME, from, to, text);
+ replace(DEFAULT_PROGRAM_NAME, from, to, text);
}
- void tqreplace(const ANTLR_USE_NAMESPACE(std)string& programName,
+ void replace(const ANTLR_USE_NAMESPACE(std)string& programName,
size_t from, size_t to,
const ANTLR_USE_NAMESPACE(std)string& text )
{
addToSortedRewriteList(programName,new ReplaceOp(from, to, text));
}
- void tqreplace( const ANTLR_USE_NAMESPACE(std)string& programName,
+ void replace( const ANTLR_USE_NAMESPACE(std)string& programName,
RefTokenWithIndex from,
RefTokenWithIndex to,
const ANTLR_USE_NAMESPACE(std)string& text )
{
- tqreplace(programName,
+ replace(programName,
from->getIndex(),
to->getIndex(),
text);
@@ -323,13 +323,13 @@ public:
void remove( const ANTLR_USE_NAMESPACE(std)string& programName,
size_t from, size_t to)
{
- tqreplace(programName,from,to,"");
+ replace(programName,from,to,"");
}
void remove( const ANTLR_USE_NAMESPACE(std)string& programName,
RefTokenWithIndex from, RefTokenWithIndex to )
{
- tqreplace(programName,from,to,"");
+ replace(programName,from,to,"");
}
void discard(int ttype) {
@@ -34,7 +34,7 @@ namespace antlr {
* augmentation or other manipulations. Tokens are index from 0..n-1
*
- * You can insert stuff, tqreplace, and delete chunks. Note that the
+ * You can insert stuff, replace, and delete chunks. Note that the
* operations are done lazily--only if you convert the buffer to a
* String. This is very efficient because you are not moving data around